@@ -22,15 +22,54 @@ describe 'cloudkitty' do
       end
 
       it 'configures rabbit' do
-        is_expected.to contain_cloudkitty_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cloudkitty_config('DEFAULT/rpc_response_timeout').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cloudkitty_config('DEFAULT/control_exchange').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cloudkitty_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cloudkitty_config('oslo_messaging_rabbit/heartbeat_rate').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cloudkitty_config('oslo_messaging_rabbit/heartbeat_in_pthread').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cloudkitty_config('oslo_messaging_rabbit/kombu_compression').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cloudkitty_config('oslo_messaging_notifications/transport_url').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cloudkitty_config('oslo_messaging_notifications/driver').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_oslo__messaging__default('cloudkitty_config').with(
+          :transport_url        => '<SERVICE DEFAULT>',
+          :rpc_response_timeout => '<SERVICE DEFAULT>',
+          :control_exchange     => '<SERVICE DEFAULT>'
+        )
+        is_expected.to contain_oslo__messaging__rabbit('cloudkitty_config').with(
+          :rabbit_use_ssl              => '<SERVICE DEFAULT>',
+          :heartbeat_timeout_threshold => '<SERVICE DEFAULT>',
+          :heartbeat_rate              => '<SERVICE DEFAULT>',
+          :heartbeat_in_pthread        => '<SERVICE DEFAULT>',
+          :kombu_reconnect_delay       => '<SERVICE DEFAULT>',
+          :kombu_failover_strategy     => '<SERVICE DEFAULT>',
+          :amqp_durable_queues         => '<SERVICE DEFAULT>',
+          :kombu_compression           => '<SERVICE DEFAULT>',
+          :kombu_ssl_ca_certs          => '<SERVICE DEFAULT>',
+          :kombu_ssl_certfile          => '<SERVICE DEFAULT>',
+          :kombu_ssl_keyfile           => '<SERVICE DEFAULT>',
+          :kombu_ssl_version           => '<SERVICE DEFAULT>',
+          :rabbit_ha_queues            => '<SERVICE DEFAULT>',
+          :rabbit_retry_interval       => '<SERVICE DEFAULT>',
+        )
+        is_expected.to contain_oslo__messaging__notifications('cloudkitty_config').with(
+          :transport_url => '<SERVICE DEFAULT>',
+          :driver        => '<SERVICE DEFAULT>',
+          :topics        => '<SERVICE DEFAULT>'
+        )
+      end
+
+      it 'configures amqp' do
+        is_expected.to contain_oslo__messaging__amqp('cloudkitty_config').with(
+          :server_request_prefix => '<SERVICE DEFAULT>',
+          :broadcast_prefix      => '<SERVICE DEFAULT>',
+          :group_request_prefix  => '<SERVICE DEFAULT>',
+          :container_name        => '<SERVICE DEFAULT>',
+          :idle_timeout          => '<SERVICE DEFAULT>',
+          :trace                 => '<SERVICE DEFAULT>',
+          :ssl_ca_file           => '<SERVICE DEFAULT>',
+          :ssl_cert_file         => '<SERVICE DEFAULT>',
+          :ssl_key_file          => '<SERVICE DEFAULT>',
+          :sasl_mechanisms       => '<SERVICE DEFAULT>',
+          :sasl_config_dir       => '<SERVICE DEFAULT>',
+          :sasl_config_name      => '<SERVICE DEFAULT>',
+          :username              => '<SERVICE DEFAULT>',
+          :password              => '<SERVICE DEFAULT>',
+        )
+      end
+
+      it 'configures storage' do
         is_expected.to contain_cloudkitty_config('storage/backend').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cloudkitty_config('storage/version').with_value('<SERVICE DEFAULT>')
       end
@@ -46,12 +85,15 @@ describe 'cloudkitty' do
     context 'with overridden parameters' do
       let :params do
         {
-          :rabbit_ha_queues                   => 'undef',
+          :rabbit_ha_queues                   => true,
           :rabbit_heartbeat_timeout_threshold => '60',
           :rabbit_heartbeat_rate              => '10',
           :rabbit_heartbeat_in_pthread        => true,
+          :kombu_reconnect_delay              => '5.0',
+          :amqp_durable_queues                => true,
           :kombu_compression                  => 'gzip',
           :package_ensure                     => '2012.1.1-15.el6',
+          :notification_driver                => 'messagingv1',
           :notification_topics                => 'openstack',
           :default_transport_url              => 'rabbit://rabbit_user:password@localhost:5673',
           :rpc_response_timeout               => '120',
@@ -64,17 +106,28 @@ describe 'cloudkitty' do
       end
 
       it 'configures rabbit' do
-        is_expected.to contain_cloudkitty_config('DEFAULT/transport_url').with_value('rabbit://rabbit_user:password@localhost:5673')
-        is_expected.to contain_cloudkitty_config('DEFAULT/rpc_response_timeout').with_value('120')
-        is_expected.to contain_cloudkitty_config('DEFAULT/control_exchange').with_value('cloudkitty')
-        is_expected.to contain_cloudkitty_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('60')
-        is_expected.to contain_cloudkitty_config('oslo_messaging_rabbit/heartbeat_rate').with_value('10')
-        is_expected.to contain_cloudkitty_config('oslo_messaging_rabbit/heartbeat_in_pthread').with_value(true)
-        is_expected.to contain_cloudkitty_config('oslo_messaging_rabbit/kombu_compression').with_value('gzip')
+        is_expected.to contain_oslo__messaging__default('cloudkitty_config').with(
+          :transport_url        => 'rabbit://rabbit_user:password@localhost:5673',
+          :rpc_response_timeout => '120',
+          :control_exchange     => 'cloudkitty'
+        )
+        is_expected.to contain_oslo__messaging__rabbit('cloudkitty_config').with(
+          :heartbeat_timeout_threshold => '60',
+          :heartbeat_rate              => '10',
+          :heartbeat_in_pthread        => true,
+          :kombu_reconnect_delay       => '5.0',
+          :amqp_durable_queues         => true,
+          :kombu_compression           => 'gzip',
+          :rabbit_ha_queues            => true,
+        )
+        is_expected.to contain_oslo__messaging__notifications('cloudkitty_config').with(
+          :transport_url => '<SERVICE DEFAULT>',
+          :driver        => 'messagingv1',
+          :topics        => 'openstack'
+        )
       end
 
       it 'configures various things' do
-        is_expected.to contain_cloudkitty_config('oslo_messaging_notifications/topics').with_value('openstack')
         is_expected.to contain_cloudkitty_config('storage/backend').with_value('gnocchi')
         is_expected.to contain_cloudkitty_config('storage/version').with_value('1')
         is_expected.to contain_cloudkitty_config('fetcher_keystone/auth_section').with_value('keystone_authtoken')
@@ -83,40 +136,6 @@ describe 'cloudkitty' do
 
     end
 
-    context 'with kombu_reconnect_delay set to 5.0' do
-      let :params do
-        { :kombu_reconnect_delay => '5.0' }
-      end
-
-      it 'configures rabbit' do
-        is_expected.to contain_cloudkitty_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('5.0')
-      end
-    end
-
-    context 'with rabbit_ha_queues set to true' do
-      let :params do
-        { :rabbit_ha_queues => 'true' }
-      end
-
-      it 'configures rabbit' do
-        is_expected.to contain_cloudkitty_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value(true)
-      end
-    end
-
-    context 'with amqp_durable_queues parameter' do
-      let :params do
-        { :amqp_durable_queues => 'true' }
-      end
-
-      it 'configures rabbit' do
-        is_expected.to contain_cloudkitty_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cloudkitty_config('oslo_messaging_rabbit/amqp_durable_queues').with_value(true)
-        is_expected.to contain_oslo__messaging__rabbit('cloudkitty_config').with(
-          :rabbit_use_ssl     => '<SERVICE DEFAULT>',
-        )
-      end
-    end
-
     context 'with rabbit ssl enabled with kombu' do
       let :params do
         { :rabbit_use_ssl     => true,
@@ -153,26 +172,6 @@ describe 'cloudkitty' do
       end
     end
 
-    context 'with amqp default parameters' do
-      it 'configures amqp' do
-        is_expected.to contain_cloudkitty_config('oslo_messaging_amqp/server_request_prefix').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cloudkitty_config('oslo_messaging_amqp/broadcast_prefix').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cloudkitty_config('oslo_messaging_amqp/group_request_prefix').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cloudkitty_config('oslo_messaging_amqp/container_name').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cloudkitty_config('oslo_messaging_amqp/idle_timeout').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cloudkitty_config('oslo_messaging_amqp/trace').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cloudkitty_config('oslo_messaging_amqp/ssl_ca_file').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cloudkitty_config('oslo_messaging_amqp/ssl_cert_file').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cloudkitty_config('oslo_messaging_amqp/ssl_key_file').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cloudkitty_config('oslo_messaging_amqp/ssl_key_password').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cloudkitty_config('oslo_messaging_amqp/sasl_mechanisms').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cloudkitty_config('oslo_messaging_amqp/sasl_config_dir').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cloudkitty_config('oslo_messaging_amqp/sasl_config_name').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cloudkitty_config('oslo_messaging_amqp/username').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cloudkitty_config('oslo_messaging_amqp/password').with_value('<SERVICE DEFAULT>')
-      end
-    end
-
     context 'with overridden amqp parameters' do
       let :params do
         { :amqp_idle_timeout  => '60',
@@ -186,13 +185,19 @@ describe 'cloudkitty' do
       end
 
       it 'configures amqp' do
-        is_expected.to contain_cloudkitty_config('oslo_messaging_amqp/idle_timeout').with_value('60')
-        is_expected.to contain_cloudkitty_config('oslo_messaging_amqp/trace').with_value('true')
-        is_expected.to contain_cloudkitty_config('oslo_messaging_amqp/ssl_ca_file').with_value('/etc/ca.cert')
-        is_expected.to contain_cloudkitty_config('oslo_messaging_amqp/ssl_cert_file').with_value('/etc/certfile')
-        is_expected.to contain_cloudkitty_config('oslo_messaging_amqp/ssl_key_file').with_value('/etc/key')
-        is_expected.to contain_cloudkitty_config('oslo_messaging_amqp/username').with_value('amqp_user')
-        is_expected.to contain_cloudkitty_config('oslo_messaging_amqp/password').with_value('password')
+        is_expected.to contain_oslo__messaging__amqp('cloudkitty_config').with(
+          :server_request_prefix => '<SERVICE DEFAULT>',
+          :broadcast_prefix      => '<SERVICE DEFAULT>',
+          :group_request_prefix  => '<SERVICE DEFAULT>',
+          :container_name        => '<SERVICE DEFAULT>',
+          :idle_timeout          => 60,
+          :trace                 => true,
+          :ssl_ca_file           => '/etc/ca.cert',
+          :ssl_cert_file         => '/etc/certfile',
+          :ssl_key_file          => '/etc/key',
+          :username              => 'amqp_user',
+          :password              => 'password',
+        )
       end
     end
 
